@@ -32,8 +32,10 @@ char* debopen(const char* filename) {
     if (fd < 0)
         return NULL;
 
-    if (fstat(fd, &statbuf) < 0)
+    if (fstat(fd, &statbuf) < 0) {
+        close(fd);
         return NULL;
+    }
 
     buf = (char*)malloc((size_t)(statbuf.st_size + 1));
 
